Values

Struct Values 

pub struct Values { /* private fields */ }
The Values type is used as the source of content during template expansion, and is a logical map of keys to typed Value (which may or may not be present during expansion).

Implementations

Source

impl Values

pub fn add(self, key: impl Into<String>, value: impl Into<Value>) -> Values

Adds a new Value to the Values collection and returns the modified collection to allow for chaining of calls during construction. Values may be any type which implements Into<Value>

  • this will generally be a concrete Value but may be your own type for which this trait has been implemented.

For clarity, it may be better to implement a suitable iterator trait for your custom type and pass it to the relevant Value construction function, as this will make the shape of data produced more obvious for anyone reading the code.

pub fn get(&self, key: &str) -> Option<&Value>

Gets the Value at the given key from the Values collection if it exists.